@@ -38,6 +38,11 @@ where not datistemplate
 order by case when datname = pg_catalog.current_database() then -1::bigint else N.oid::bigint end
 ;
 
+---- ListLanguages ----
+select lanname
+from pg_catalog.pg_language
+order by lanname
+;
 
 ---- ListSchemas ----
 select N.oid::bigint as id,
@@ -718,7 +723,7 @@ select T.table_id,
        pg_catalog.format_type(C.atttypid, C.atttypmod) as type_spec,
        C.atttypid as type_id,
        C.attnotnull as mandatory,
-       #V120: pg_catalog.pg_get_expr(D.adbin, 'pg_catalog.pg_attrdef'::regclass::oid) #: D.adsrc #. as column_default_expression,
+       #V120: pg_catalog.pg_get_expr(D.adbin, T.table_id) #: D.adsrc #. as column_default_expression,
        not C.attislocal as column_is_inherited,
        #V92> C.attfdwoptions as options,
        C.attisdropped as column_is_dropped,
@@ -1055,7 +1060,9 @@ select T.tgrelid as table_id,
        T.tgtype & 31 as bits,
        T.tgdeferrable as is_deferrable,
        T.tginitdeferred as is_init_deferred,
-       T.tgenabled as trigger_fire_mode
+       T.tgenabled as trigger_fire_mode,
+       T.tgattr as columns,
+       pg_catalog.pg_get_triggerdef(T.oid, true) as source_code
 from pg_catalog.pg_trigger T
 where T.tgrelid in (select oid
                     from pg_catalog.pg_class
@@ -1069,7 +1076,7 @@ where T.tgrelid in (select oid
 select distinct
        T.relkind as view_kind,
        T.oid as view_id,
-       pg_catalog.pg_get_viewdef(T.oid) as source_text
+       pg_catalog.pg_get_viewdef(T.oid, true) as source_text
 from pg_catalog.pg_class T
   join pg_catalog.pg_namespace N on T.relnamespace = N.oid
   left outer join pg_catalog.pg_attribute A on (A.attrelid = T.oid)
@@ -1087,7 +1094,7 @@ with A as ( select oid as table_id, pg_catalog.upper(relkind) as table_kind
 select table_kind,
        table_id,
        R.oid as rule_id,
-       pg_catalog.pg_get_ruledef(R.oid) as source_text
+       pg_catalog.pg_get_ruledef(R.oid, true) as source_text
 from A join pg_catalog.pg_rewrite R
         on A.table_id = R.ev_class
 where R.rulename != '_RETURN'::name
